@@ -15,7 +15,7 @@
 
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import forms
 from horizon import tables
 from horizon import tabs
