@@ -12,15 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from cloudkittydashboard.dashboards.admin.pyscripts import views
 
 urlpatterns = [
-    url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^create/?$', views.ScriptCreateView.as_view(), name="script_create"),
-    url(r'^update/(?P<script_id>[^/]+)/?$', views.ScriptUpdateView.as_view(),
-        name="script_update"),
-    url(r'^(?P<script_id>[^/]+)/?$', views.ScriptDetailsView.as_view(),
-        name="script_details"),
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^create/?$', views.ScriptCreateView.as_view(),
+            name="script_create"),
+    re_path(r'^update/(?P<script_id>[^/]+)/?$',
+            views.ScriptUpdateView.as_view(),
+            name="script_update"),
+    re_path(r'^(?P<script_id>[^/]+)/?$', views.ScriptDetailsView.as_view(),
+            name="script_details"),
     ]
